import math


def gen_keys(p, q, e):
    '''
    eng: This system function is needed for the correct operation of the module

    rus: Это системная функция нужна для корректной работы модуля

    :param p:
    :param q:
    :param e:
    :return :
    '''
    n = p * q
    f = (p - 1) * (q - 1)
    while math.gcd(e, f) != 1:
        e += 2
        if e > f:
            print("error")
    d = pow(e, -1, f)
    e = e
    return e, d, n



from setuptools import setup


def readme():
    with open('README.md', 'r') as f:
        return f.read()


setup(
    name='rsatool',
    version='0.1.8',
    description='Module for fast calculating large primes, and RSA encryption and decryption of data of any size',
    long_description=readme(),
    long_description_content_type='text/markdown',
    author='Nikita Grigorev',
    author_email='nekitbilding@inbox.ru',
    url='https://github.com/mrNikGrig/RSA_tool.git',
    packages=['rsatool']
)
